@@ -22,7 +22,7 @@ if ( ! function_exists('awsslPreCheck') ) {
 		// 
 		//*****************************************************************************/
 		include( dirname(dirname(__FILE__)) .'/init.php' );
-		
+
 		//*****************************************************************************/
 		// ⥸塼꤬Ǥʤϥå
 		//*****************************************************************************/
@@ -33,52 +33,39 @@ if ( ! function_exists('awsslPreCheck') ) {
 			//*************************************************************************/
 			include( $mod_path .'/class/anywheressl.class.php' );
 			$Anywheressl = new Anywheressl( $awssl_config );
-			
+			$current_url = $Anywheressl->getCurrentUrl();
+
 			//*************************************************************************/
 			// ɺѤߤåԤ
 			//*************************************************************************/
 			$awssl_loaded = !empty( $_SESSION['AWSSL_LOADED'] ) ? true : false;
-			
+
 			//*************************************************************************/
-			// åΥåȤԤ
+			// SSLȽѥåΥåȤԤ
 			//*************************************************************************/
 			$Anywheressl->setSecureCookie();
-			
+
 			//*************************************************************************/
-			// ɺѤߤǤʤ硢̤
+			// åͭʤ顢ɺѤߤݤȽԤ
 			//*************************************************************************/
-			if ( ! $awssl_loaded ) {
-				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
-				$query_string = !empty( $_SERVER['QUERY_STRING'] ) ? '?' .$_SERVER['QUERY_STRING'] : '';
-				header( "Location: " .$current_script .$query_string );
-			}
-			
-			//*************************************************************************/
-			// SSL/SSLڤؤȤƥåIDղäƤ
-			//*************************************************************************/
-			$session_name = urldecode( $awssl_config['session_name']['conf_value'] );
-			if ( ! empty($_GET[$session_name]) ) {
-				// MyTextSanitizer󥹥󥹤
-				$myts =& MyTextSanitizer::getInstance();
-				$session_id = $myts->stripSlashesGPC( $_GET[$session_name] );
-				if ( preg_match('/[^a-zA-Z0-9*]{32}$/i', $session_id, $matches) ) {
-					redirect_header( XOOPS_URL, 2, AWSSL_ERR_ILLEGITIMATE_OP );
-					exit;
+			if ( ! empty($_COOKIE) || ini_get('session.use_only_cookies') !== '1' ) {
+				//*********************************************************************/
+				// ɺѤߤǤʤ硢̤
+				//*********************************************************************/
+				if ( ! $awssl_loaded ) {
+					//*****************************************************************/
+					// ΤߡXOOPS_ROOT_PATH/include/checklogin.phpinclude
+					//*****************************************************************/
+					if ( ($_SERVER['SCRIPT_FILENAME'] === XOOPS_ROOT_PATH .'/user.php') &&
+						($_SERVER['REQUEST_METHOD'] === 'POST') &&
+						(!empty($_POST['op']) && $_POST['op'] === 'login') ) {
+						include_once( XOOPS_ROOT_PATH.'/include/checklogin.php' );
+						exit;
+					}
+					header( "Location: " .$current_url );
 				}
-				// ˳Ǽå
-				$Anywheressl->getAwsslSession( $session_id );
-				// åDB
-				$Anywheressl->delAwsslSession( $session_id );
-				// $_GETǥåIDϤƤ뤿ᡢ٥åIDѹ
-				$Anywheressl->awsslSessionRegenerateId( $regenerate = true );
-				// åIDURL
-				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
-				$query_string = str_replace( $session_name .'=' .$session_id , '', $_SERVER['QUERY_STRING'] );
-				$query_string = !empty( $query_string ) ? substr( $query_string, 0, strlen($query_string) - 1 ) : '';
-				$query_string = !empty( $query_string ) ? '?' .$query_string : '';
-				header( "Location: " .$current_script .$query_string );
 			}
-		
+
 			//*************************************************************************/
 			// 奢°ղáʥåIDڤؤ"Ϥ"ξڤؤ
 			//*************************************************************************/
@@ -86,18 +73,23 @@ if ( ! function_exists('awsslPreCheck') ) {
 			$Anywheressl->awsslSessionRegenerateId( $regenerate = $session_regenerate_id );
 
 			//*************************************************************************/
+			// 
+			//*************************************************************************/
+			// Хåե󥰽ؿΥեɤ߹
+			require_once( dirname(__FILE__) .'/buffering.inc.php' );
 			// SSL-Loginοƥɥν񤭴
-			//*************************************************************************/
-			$current_url = $Anywheressl->getCurrentUrl();
 			if ( $current_url === XOOPS_URL .'/misc.php?action=showpopups&type=ssllogin' ) {
-				include_once( $mod_path .'/include/sslloginbuf.inc.php' );
+				ob_start( 'awsslLoginPhpBuf' );
 			}
-		} else {
+			// SSL/SSLURL񤭴xoops_redirectν񤭴
+			ob_start( 'awsslDefaultBuf' );
+
 			//*************************************************************************/
-			// ܶػߥե饰
+			// (XOOPS_URL/admin.php)ξΤߡ֥åƱͤνԤ
 			//*************************************************************************/
-			if ( ! defined( 'AWSSL_CANNOT_DESTINE' ) ) {
-				define( 'AWSSL_CANNOT_DESTINE', 1 );
+			if ( $current_url === XOOPS_URL .'/admin.php' ) {
+				include_once( $mod_path .'/blocks/anywheressl.php' );
+				show_anywheressl_block();
 			}
 		}
 	}
@@ -106,5 +98,4 @@ if ( ! function_exists('awsslPreCheck') ) {
 
 }
 
-
 ?>
\ No newline at end of file
