@@ -24,3 +24,18 @@ CREATE TABLE `anywheressl_configs` (
   PRIMARY KEY  (`conf_id`),
   KEY `conf_name` (`conf_name`)
 ) TYPE=MyISAM ;
+
+
+-- --------------------------------------------------------
+
+-- 
+-- e[u̍\ `anywheressl_enforce`
+-- 
+
+CREATE TABLE `anywheressl_enforce` (
+  `fid` smallint(5) unsigned NOT NULL auto_increment,
+  `mid` smallint(5) unsigned NOT NULL default '0',
+  `script_filename` varchar(30) NOT NULL default '',
+  PRIMARY KEY  (`fid`),
+  KEY `mid` (`mid`,`script_filename`)
+) TYPE=MyISAM ;
