@@ -12,7 +12,7 @@ if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;
 //⥸塼̾
 $modversion['name'] = _MI_AWSSL_MOD_NAME;
 //⥸塼ΥС
-$modversion['version'] = '0.3.3';
+$modversion['version'] = '0.4.1';
 //⥸塼
 $modversion['description'] = _MI_AWSSL_MOD_DESC;
 //⥸塼Υ쥸åɸ
@@ -47,7 +47,8 @@ $modversion['sqlfile']['mysql'] = "sql/mysql.sql";
 
 $modversion['tables'] = array(
 	"anywheressl",
-	"anywheressl_configs"
+	"anywheressl_configs",
+	"anywheressl_enforce"
 );
 
 
@@ -64,7 +65,7 @@ $modversion['onInstall'] = 'include/oninstall.inc.php';
 //onupdate.inc.phpǤxoops_module_update_(⥸塼̾)Ȥ
 //ؿ˽򵭽Ҥޤ
 //⥸塼ΥåץǡȤλΤˤν¹Ԥޤ
-//$modversion['onUpdate'] = '';
+$modversion['onUpdate'] = 'include/oninstall.inc.php';
 
 //**************************************************************
 //󥤥󥹥ȡϢ
